@@ -23,10 +23,7 @@
 #ifndef SEARCH_H
 #define SEARCH_H 1
 
+int check_paths (char *, char *);
 void start_search (void);
-int forbidden (char *);
-int excluded (char *);
-int searched (char *);
-void search_path (char *);
 
 #endif /* SEARCH_H */
