@@ -21,6 +21,7 @@
  */
 
 #include <stdlib.h>
+#include <unistd.h>
 #include <strings.h>
 #include <stdio.h>
 #include <sys/stat.h>
@@ -102,7 +103,23 @@ void init_file_entries (void)
 /* Initializes comparison functions */
 void compare_output (void)
 {
-    mail_file = tmpfile ();
+    char *tmp_dir, *tmp_file;
+
+    tmp_dir = getenv("TMPDIR");
+    if (tmp_dir == NULL)
+	tmp_dir = "/tmp";
+
+    tmp_file = malloc(strlen(tmp_dir) + strlen("/sxid.XXXXXX") + 1);
+    if (tmp_file == NULL) {
+	fprintf (stderr, "E: could not malloc() in compare_output().\n");
+	exit (1);
+    }
+    strcpy(tmp_file, tmp_dir);
+    strcat(tmp_file, "/sxid.XXXXXX");
+
+    mail_file = fdopen(mkstemp(tmp_file), "w+b");
+    unlink(tmp_file);
+    free(tmp_file);
 
     if (mail_file == NULL) {
 	fprintf (stderr, "E: could not open temp file in compare_output().\n");
